Stan Math Library: stan/math/prim/mat/fun/log_determinant_ldlt.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_determinant_ldlt.hpp File Reference
`#include <stan/math/prim/mat/fun/LDLT_factor.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C, typename T >
T | stan::math::log_determinant_ldlt (stan::math::LDLT_factor< T, R, C > &A)

[ Stan Home Page ] © 2011–2016, Stan Development Team.